==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigProxyFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigProxyFluent<A extends ImageRegistryConfigProxyFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigProxyFluent() {
  }
  
  public ImageRegistryConfigProxyFluent(ImageRegistryConfigProxy instance) {
    this.copyInstance(instance);
  }
  private String http;
  private String https;
  private String noProxy;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigProxy instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigProxy());
  
    if (instance != null) {
        this.withHttp(instance.getHttp());
        this.withHttps(instance.getHttps());
        this.withNoProxy(instance.getNoProxy());
        this.withHttp(instance.getHttp());
        this.withHttps(instance.getHttps());
        this.withNoProxy(instance.getNoProxy());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getHttp() {
    return this.http;
  }
  
  public A withHttp(String http) {
    this.http=http; return (A) this;
  }
  
  public boolean hasHttp() {
    return this.http != null;
  }
  
  public String getHttps() {
    return this.https;
  }
  
  public A withHttps(String https) {
    this.https=https; return (A) this;
  }
  
  public boolean hasHttps() {
    return this.https != null;
  }
  
  public String getNoProxy() {
    return this.noProxy;
  }
  
  public A withNoProxy(String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  
  public boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigProxyFluent that = (ImageRegistryConfigProxyFluent) o;
    if (!java.util.Objects.equals(http, that.http)) return false;
  
    if (!java.util.Objects.equals(https, that.https)) return false;
  
    if (!java.util.Objects.equals(noProxy, that.noProxy)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(http,  https,  noProxy,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (https != null) { sb.append("https:"); sb.append(https + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigProxyFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigProxyFluent<A extends ImageRegistryConfigProxyFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigProxyFluent() {
  }
  
  public ImageRegistryConfigProxyFluent(ImageRegistryConfigProxy instance) {
    this.copyInstance(instance);
  }
  private String http;
  private String https;
  private String noProxy;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigProxy instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigProxy());
    if (instance != null) {
          this.withHttp(instance.getHttp());
          this.withHttps(instance.getHttps());
          this.withNoProxy(instance.getNoProxy());
          this.withHttp(instance.getHttp());
          this.withHttps(instance.getHttps());
          this.withNoProxy(instance.getNoProxy());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getHttp() {
    return this.http;
  }
  
  public A withHttp(String http) {
    this.http = http;
    return (A) this;
  }
  
  public boolean hasHttp() {
    return this.http != null;
  }
  
  public String getHttps() {
    return this.https;
  }
  
  public A withHttps(String https) {
    this.https = https;
    return (A) this;
  }
  
  public boolean hasHttps() {
    return this.https != null;
  }
  
  public String getNoProxy() {
    return this.noProxy;
  }
  
  public A withNoProxy(String noProxy) {
    this.noProxy = noProxy;
    return (A) this;
  }
  
  public boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigProxyFluent that = (ImageRegistryConfigProxyFluent) o;
    if (!java.util.Objects.equals(http, that.http)) return false;
    if (!java.util.Objects.equals(https, that.https)) return false;
    if (!java.util.Objects.equals(noProxy, that.noProxy)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(http,  https,  noProxy,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (https != null) { sb.append("https:"); sb.append(https + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
